.. spvideoutils documentation master file, created by
   sphinx-quickstart on Thu May 26 03:46:51 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to spvideoutils documentation!
========================================
Is a collection of useful scripts for handling the camera.

Scripts
--------
- video_capture
   * Captures the video from the camera to a mp4 file.

- video_split
   * Splits the mp4 video file to frames stored as png files.

- video_merge
   * Merges the frames in png file to mp4 file.

- video_crop
   * Crops the video mp4 file from frame i to frame j.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   camera
   video_capture
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
